@@ -4,10 +4,11 @@
 /* Author: Rainer Doemer			first version: 10/08/97 */
 /************************************************************************/
 
-/* last update:	05/31/01 */
+/* last update:	06/05/01 */
 
 /* modifications: (most recent first)
  *
+ * 06/05/00 RD	applied another bug fix in SIR_UserType::ContainsNested()
  * 05/31/01 RD	eliminated level 2 of SIR API
  * 05/25/01 RD	eliminated support for binary SIR files (import/export)
  * 04/30/01 RD	replaced use of obsolete form() from "stream.h" with own one
@@ -162,6 +163,7 @@ BOOL SIR_UserType::ContainsNested(	/* checks for nested struct/union */
 	sir_usertype	*UserType)	/* (struct/union definitions only) */
 {
 sir_member	*Member;
+sir_type	*MemberType;
 
 assert(UserType != NULL);	/* argument must have been specified */
 assert(UserType->Class != SIR_USERTYPE_ENUM);	/* must not be enum-type */
@@ -169,12 +171,16 @@ assert(Members != NULL);	/* this must be a definition */
 
 Member = Members->First();
 while(Member)
-   { if (Member->Type->UserType)
-	{ if (Member->Type->UserType == UserType)
+   { MemberType = Member->Type;			/* bug fix (06/05/01, RD) */
+     while (MemberType->Type == SIR_TYPE_ARRAY)	/* go into array types    */
+	{ MemberType = MemberType->SubType;
+	 } /* elihw */
+     if (MemberType->UserType)
+	{ if (MemberType->UserType == UserType)
 	     { return(TRUE);		/* this contains def. of UserType */
 	      } /* fi */
-	  if (  (Member->Type->UserType->Class != SIR_USERTYPE_ENUM)
-	      &&(Member->Type->UserType->ContainsNested(UserType)))
+	  if (  (MemberType->UserType->Class != SIR_USERTYPE_ENUM)
+	      &&(MemberType->UserType->ContainsNested(UserType)))
 	     { return(TRUE);		/* child contains def. of UserType */
 	      } /* fi */
 	 } /* fi */
